You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@madlib.apache.org by nj...@apache.org on 2018/06/27 21:56:51 UTC

madlib git commit: Infra: Use dev-check in Jenkins build

Repository: madlib
Updated Branches:
  refs/heads/master d2cc6c68a -> 887a086cb


Infra: Use dev-check in Jenkins build

Jenkins builds (both PR and master) are currently still running only
install-check. This commit now runs dev-check instead.


Project: http://git-wip-us.apache.org/repos/asf/madlib/repo
Commit: http://git-wip-us.apache.org/repos/asf/madlib/commit/887a086c
Tree: http://git-wip-us.apache.org/repos/asf/madlib/tree/887a086c
Diff: http://git-wip-us.apache.org/repos/asf/madlib/diff/887a086c

Branch: refs/heads/master
Commit: 887a086cb95656b3f87b692231da1719485c4858
Parents: d2cc6c6
Author: Nandish Jayaram <nj...@apache.org>
Authored: Wed Jun 27 14:52:36 2018 -0700
Committer: Nandish Jayaram <nj...@apache.org>
Committed: Wed Jun 27 14:52:36 2018 -0700

----------------------------------------------------------------------
 tool/jenkins/jenkins_build.sh | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/madlib/blob/887a086c/tool/jenkins/jenkins_build.sh
----------------------------------------------------------------------
diff --git a/tool/jenkins/jenkins_build.sh b/tool/jenkins/jenkins_build.sh
index 0dce943..c159b5e 100644
--- a/tool/jenkins/jenkins_build.sh
+++ b/tool/jenkins/jenkins_build.sh
@@ -66,8 +66,8 @@ docker exec madlib bash -c 'rm -rf /build; mkdir /build; cd /build; cmake ../mad
 EOF
 docker exec madlib bash -c 'rm -rf /build; mkdir /build; cd /build; cmake ../madlib; make clean; make; make install; make package' | tee $workdir/logs/madlib_compile.log
 
-echo "---------- Installing and running install-check --------------------"
-# Install MADlib and run install check
+echo "---------- Installing and running dev-check --------------------"
+# Install MADlib and run dev check
 cat <<EOF
 docker exec madlib bash -c '/build/src/bin/madpack -s mad -p postgres -c postgres/postgres@localhost:5432/postgres install' | tee $workdir/logs/madlib_install.log
 EOF
@@ -75,11 +75,11 @@ docker exec madlib bash -c '/build/src/bin/madpack -s mad -p postgres -c postgre
 
 cat <<EOF
 docker exec madlib bash -c 'mkdir /tmp'
-docker exec madlib bash -c '/build/src/bin/madpack -s mad -p postgres  -c postgres/postgres@localhost:5432/postgres -d /tmp install-check' | tee $workdir/logs/madlib_install_check.log
+docker exec madlib bash -c '/build/src/bin/madpack -s mad -p postgres  -c postgres/postgres@localhost:5432/postgres -d /tmp dev-check' | tee $workdir/logs/madlib_dev_check.log
 EOF
 
 docker exec madlib bash -c 'mkdir /tmp'
-docker exec madlib bash -c '/build/src/bin/madpack -s mad -p postgres  -c postgres/postgres@localhost:5432/postgres -d /tmp install-check' | tee $workdir/logs/madlib_install_check.log
+docker exec madlib bash -c '/build/src/bin/madpack -s mad -p postgres  -c postgres/postgres@localhost:5432/postgres -d /tmp dev-check' | tee $workdir/logs/madlib_dev_check.log
 
 echo "--------- Copying packages -----------------"
 echo "docker cp madlib:build $workdir"
@@ -95,8 +95,8 @@ echo "ls -la build"
 ls -la build/
 echo "-------------------------------"
 
 # convert install-check test results to junit format for reporting
 cat <<EOF
-python ${reponame}/tool/jenkins/junit_export.py $workdir/logs/madlib_install_check.log $workdir/logs/madlib_install_check.xml
+python ${reponame}/tool/jenkins/junit_export.py $workdir/logs/madlib_dev_check.log $workdir/logs/madlib_dev_check.xml
 EOF
-python ${reponame}/tool/jenkins/junit_export.py $workdir $workdir/logs/madlib_install_check.log $workdir/logs/madlib_install_check.xml
+python ${reponame}/tool/jenkins/junit_export.py $workdir $workdir/logs/madlib_dev_check.log $workdir/logs/madlib_dev_check.xml
@@ -95,8 +95,8 @@ echo "ls -la build"
 echo "-------------------------------"
 
-# convert install-check test results to junit format for reporting
+# convert dev-check test results to junit format for reporting
 cat <<EOF